@@ -128,7 +128,7 @@ def _get_query_dict(env, reqbody, reqtype):
                     qdict[ky] = na
                 else:
                     qdict[ky] = pbody[ky][0]
-        elif 'application/json' == reqtype:
+        elif 'application/json' in reqtype:
             pbody = json.loads(reqbody)
             for key in pbody.iterkeys():
                 qdict[key] = pbody[key]
@@ -334,12 +334,18 @@ def resourcehandler_backend(env, start_response):
             consolesessions[sessid]['expiry'] = time.time() + 90
             outdata = consolesessions[sessid]['session'].get_next_output(
                 timeout=45)
+            bufferage = False
+            if 'stampsent' not in consolesessions[sessid]:
+                consolesessions[sessid]['stampsent'] = True
+                bufferage = consolesessions[sessid]['session'].get_buffer_age()
             if isinstance(outdata, dict):
                 rspdata = outdata
                 rspdata['session'] = querydict['session']
             else:
                 rspdata = {'session': querydict['session'],
                            'data': outdata}
+            if bufferage is not False:
+                rspdata['bufferage'] = bufferage
             try:
                 rsp = json.dumps(rspdata)
             except UnicodeDecodeError:
