@@ -19,10 +19,12 @@
 # It implement unix and tls sockets
 # 
 
+import atexit
 import os
 import pwd
 import stat
 import struct
+import sys
 import traceback
 
 import eventlet.green.socket as socket
@@ -110,6 +112,8 @@ def sessionhdl(connection, authname, skipauth=False):
             tlvdata.send(connection, {'errorcode': 504,
                                       'error': 'Unreachable Target'})
             tlvdata.send(connection, {'_requestdone': 1})
+        except SystemExit:
+            sys.exit(0)
         except:
             tracelog.log(traceback.format_exc(), ltype=log.DataTypes.event,
                          event=log.Events.stacktrace)
@@ -163,6 +167,9 @@ def process_request(connection, request, cfm, authdata, authname, skipauth):
                 raise Exception("TODO")
             tlvdata.send(connection, {'started': 1})
             ccons.startsending()
+            bufferage = consession.get_buffer_age()
+            if bufferage is not False:
+                tlvdata.send(connection, {'bufferage': bufferage})
             while consession is not None:
                 data = tlvdata.recv(connection)
                 if type(data) == dict:
@@ -181,6 +188,8 @@ def process_request(connection, request, cfm, authdata, authname, skipauth):
                     consession.destroy()
                     return
                 consession.write(data)
+        elif operation == 'shutdown':
+            configmanager.ConfigManager.shutdown()
         else:
             hdlr = pluginapi.handle_path(path, operation, cfm, params)
     except exc.NotFoundException:
@@ -214,6 +223,11 @@ def _tlsstartup(cnn):
                           server_side=True)
     sessionhdl(cnn, authname)
 
+def removesocket():
+    try:
+        os.remove("/var/run/confluent/api.sock")
+    except OSError:
+        pass
 
 def _unixdomainhandler():
     unixsocket = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
@@ -225,6 +239,7 @@ def _unixdomainhandler():
     os.chmod("/var/run/confluent/api.sock",
              stat.S_IWOTH | stat.S_IROTH | stat.S_IWGRP |
              stat.S_IRGRP | stat.S_IWUSR | stat.S_IRUSR)
+    atexit.register(removesocket)
     unixsocket.listen(5)
     while True:
         cnn, addr = unixsocket.accept()
